print("import: 'cvxopt'")
import cvxopt

print("import: 'cvxopt.base'")
import cvxopt.base

print("import: 'cvxopt.blas'")
import cvxopt.blas

print("import: 'cvxopt.cholmod'")
import cvxopt.cholmod

print("import: 'cvxopt.lapack'")
import cvxopt.lapack

print("import: 'cvxopt.misc_solvers'")
import cvxopt.misc_solvers

print("import: 'cvxopt.umfpack'")
import cvxopt.umfpack

print("import: 'cvxopt.glpk'")
import cvxopt.glpk

print("import: 'cvxopt.fftw'")
import cvxopt.fftw

